import pytest
from typing import Generator, Any
from fastapi import FastAPI
from fastapi.testclient import TestClient
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker, Session
import os
import sys

# Добавляем корень проекта в sys.path для импорта app
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from app.main import app as main_app # Импортируем наше FastAPI приложение
from app.db.session import get_db, Base # Импортируем get_db и Base
from app.core.config import settings # Импортируем настройки

# Используем отдельную SQLite базу данных для тестов (in-memory)
TEST_DATABASE_URL = "sqlite:///:memory:"

engine = create_engine(
    TEST_DATABASE_URL, connect_args={"check_same_thread": False}
)
TestingSessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

# Фикстура для создания таблиц перед тестами и удаления после
@pytest.fixture(scope="session", autouse=True)
def setup_db():
    Base.metadata.create_all(bind=engine) # Создаем таблицы
    yield
    Base.metadata.drop_all(bind=engine) # Удаляем таблицы после тестов

# Фикстура для переопределения зависимости get_db
@pytest.fixture(scope="function") # scope="function" чтобы каждая функция получала чистую сессию
def db_session() -> Generator[Session, Any, None]:
    connection = engine.connect()
    transaction = connection.begin()
    session = TestingSessionLocal(bind=connection)
    yield session
    session.close()
    transaction.rollback() # Откатываем изменения после каждого теста
    connection.close()

# Фикстура для FastAPI TestClient
@pytest.fixture(scope="module")
def client(db_session: Session) -> Generator[TestClient, Any, None]:
    # Функция для переопределения зависимости get_db
    def override_get_db():
        try:
            yield db_session
        finally:
            # Сессия закрывается в фикстуре db_session
            pass

    # Применяем переопределение зависимости к нашему приложению
    main_app.dependency_overrides[get_db] = override_get_db
    # Создаем TestClient
    with TestClient(main_app) as c:
        yield c
    # Очищаем переопределение после тестов модуля
    main_app.dependency_overrides.clear() 