import React, { useState } from 'react';
import { useForm, SubmitHandler } from 'react-hook-form';
import { useNavigate } from 'react-router-dom';
import { runCalculation } from '../api/calculationApi';
import { CalculationCreate, CalculationFormData } from '../types';
// Импортируем стили как объект
import styles from './CalculationForm.module.css'; // Убедитесь, что этот файл существует

const CalculationForm: React.FC = () => {
  console.log("CalculationForm Рендерится! (Полная версия)"); // Обновим лог
  const navigate = useNavigate();
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const {
    register,
    handleSubmit,
    formState: { errors },
  } = useForm<CalculationFormData>({
      defaultValues: {
          sheetWidth: 2500,
          sheetHeight: 1600,
          pieceList: "500x300\n400x300\n200x200",
          modelName: "default_fuzzy_model_v1"
      }
  });

  const onSubmit: SubmitHandler<CalculationFormData> = async (formData) => {
    setIsLoading(true);
    setError(null);
    console.log('Form Data:', formData);

    const apiData: CalculationCreate = {
      input_params: {
        sheet_dimensions: {
            width: formData.sheetWidth,
            height: formData.sheetHeight,
        },
        pieces_raw: formData.pieceList,
      },
      model_name: formData.modelName || null,
    };

    try {
      console.log('Sending to API:', apiData);
      const result = await runCalculation(apiData);
      console.log('API Result:', result);
      navigate(`/calculation/${result.id}`);
    } catch (err) {
      console.error("API Error:", err);
      // Попробуем получить более детальную ошибку от axios, если возможно
      let errorMessage = 'Ошибка при запуске расчета. Попробуйте снова.';
      if (axios.isAxiosError(err)) { // Проверка типа ошибки axios
          if (err.response) {
              // Ошибка пришла с ответом от сервера (например, 4xx, 5xx)
              errorMessage = `Ошибка сервера: ${err.response.status}. ${err.response.data?.detail || err.message}`;
          } else if (err.request) {
              // Запрос был сделан, но ответа не было (сеть, CORS)
              errorMessage = `Ошибка сети или CORS. Не удалось связаться с сервером. (${err.message})`;
          } else {
              // Ошибка при настройке запроса
              errorMessage = `Ошибка настройки запроса: ${err.message}`;
          }
      } else if (err instanceof Error) { // Обычная ошибка JS
        errorMessage = err.message;
      }
      setError(errorMessage);
    } finally {
      setIsLoading(false);
    }
  };

  return (
    // Используем класс из App.css и стили модуля
    <div className={`page-container ${styles.formContainer}`}>
      <h2>Ввод параметров расчета</h2>
      <form onSubmit={handleSubmit(onSubmit)}>
        {/* Поле Ширина листа */}
        <div className={styles.formGroup}>
          <label htmlFor="sheetWidth" className={styles.label}>Ширина листа (мм):</label>
          <input
            id="sheetWidth"
            type="number"
            className={styles.input}
            {...register('sheetWidth', {
              required: 'Ширина обязательна',
              valueAsNumber: true,
              min: { value: 100, message: 'Минимальная ширина 100 мм' },
            })}
          />
          {errors.sheetWidth && <p className={styles.errorMessage}>{errors.sheetWidth.message}</p>}
        </div>

        {/* Поле Высота листа */}
        <div className={styles.formGroup}>
          <label htmlFor="sheetHeight" className={styles.label}>Высота листа (мм):</label>
          <input
            id="sheetHeight"
            type="number"
            className={styles.input}
            {...register('sheetHeight', {
              required: 'Высота обязательна',
              valueAsNumber: true,
              min: { value: 100, message: 'Минимальная высота 100 мм' },
            })}
          />
          {errors.sheetHeight && <p className={styles.errorMessage}>{errors.sheetHeight.message}</p>}
        </div>

        {/* Поле Список деталей */}
        <div className={styles.formGroup}>
          <label htmlFor="pieceList" className={styles.label}>Список деталей (формат: ШхВ, каждая с новой строки):</label>
          <textarea
            id="pieceList"
            rows={6}
            className={styles.textarea}
            {...register('pieceList', {
              required: 'Список деталей обязателен',
              pattern: {
                  value: /^(\d+x\d+\s*(\r\n|\r|\n)?)+$/,
                  message: 'Неверный формат списка деталей (ожидается ШхВ на каждой строке)'
              }
            })}
          />
          {errors.pieceList && <p className={styles.errorMessage}>{errors.pieceList.message}</p>}
        </div>

         {/* Поле Имя модели (опционально) */}
        <div className={styles.formGroup}>
          <label htmlFor="modelName" className={styles.label}>Имя модели (опционально):</label>
          <input
            id="modelName"
            type="text"
            className={styles.input}
            {...register('modelName')}
          />
        </div>

        {/* Отображение общей ошибки API */}
        {error && <p className={styles.errorMessage}>{error}</p>}

        {/* Кнопка отправки */}
        <button type="submit" disabled={isLoading} className={styles.submitButton}>
          {isLoading ? 'Загрузка...' : 'Запустить расчет'}
        </button>
      </form>
    </div>
  );
};

// Импорт axios для проверки типа ошибки
import axios from 'axios';

export default CalculationForm; 