import React, { useState, useEffect } from 'react';
import { useParams } from 'react-router-dom';
import { getCalculationById } from '../api/calculationApi';
import { CalculationRead } from '../types';
// Импортируем вспомогательные компоненты
import JsonViewer from '../components/common/JsonViewer';
import LayoutVisualizer from '../components/common/LayoutVisualizer';
// Импортируем стили
import styles from './CalculationResult.module.css';

const CalculationResult: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const [calculation, setCalculation] = useState<CalculationRead | null>(null);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    if (!id) {
      setError("ID расчета не указан.");
      setIsLoading(false);
      return;
    }

    const calculationId = parseInt(id, 10); // Преобразуем ID в число
    if (isNaN(calculationId)) {
        setError("Некорректный ID расчета.");
        setIsLoading(false);
        return;
    }

    const fetchCalculation = async () => {
      setIsLoading(true);
      setError(null);
      try {
        const data = await getCalculationById(calculationId);
        setCalculation(data);
      } catch (err: any) { // Указываем тип any или AxiosError
        console.error(`Failed to fetch calculation ${calculationId}:`, err);
        // Проверяем, была ли это ошибка 404 от нашего API
        if (err.response && err.response.status === 404) {
             setError(`Расчет с ID ${calculationId} не найден.`);
        } else {
             setError('Не удалось загрузить детали расчета.');
        }
      } finally {
        setIsLoading(false);
      }
    };

    fetchCalculation();
  }, [id]); // Зависимость от ID, чтобы перезагружать при изменении ID в URL

  if (isLoading) {
    return <div className={styles.loading}>Загрузка данных расчета ID: {id}...</div>;
  }

  if (error) {
    return <div className={styles.error}>Ошибка: {error}</div>;
  }

  if (!calculation) {
    // Это состояние не должно достигаться, если ID корректен и нет ошибки,
    // но лучше добавить проверку
    return <div>Данные расчета не найдены.</div>;
  }

  return (
    <div className={`page-container ${styles.resultContainer}`}>
      <h2>Результаты расчета ID: {calculation.id}</h2>

      <div className={styles.detailSection}>
        <div className={styles.detailTitle}>Время запуска:</div>
        <div className={styles.detailValue}>{new Date(calculation.timestamp).toLocaleString()}</div>
      </div>

      <div className={styles.detailSection}>
        <div className={styles.detailTitle}>Использованная модель:</div>
        <div className={styles.detailValue}>{calculation.model_name || '-'}</div>
      </div>

      <div className={styles.detailSection}>
        <div className={styles.detailTitle}>Входные параметры:</div>
        <JsonViewer data={calculation.input_params} />
      </div>

      <div className={styles.detailSection}>
        <div className={styles.detailTitle}>Результаты расчета (JSON):</div>
        <JsonViewer data={calculation.output_results} />
      </div>

       <div className={styles.detailSection}>
        <div className={styles.detailTitle}>Целевая функция (Остаток %):</div>
        <div className={styles.detailValue}>{calculation.objective_score?.toFixed(2) ?? '-'}</div>
      </div>

       {/* Добавляем визуализацию, если есть данные */}
       {calculation.output_results && calculation.output_results.layout && (
           <div className={styles.detailSection}>
              <LayoutVisualizer layout={calculation.output_results.layout} />
            </div>
       )}
    </div>
  );
};

export default CalculationResult; 