import React, { useState, useEffect } from 'react';
import { Link } from 'react-router-dom'; // Для ссылок на детальные страницы
import { getCalculationHistory } from '../api/calculationApi'; // API функция
import { CalculationRead } from '../types'; // Тип расчета
// Импортируем стили
import styles from './History.module.css';

const History: React.FC = () => {
  // Состояние для хранения списка расчетов
  const [calculations, setCalculations] = useState<CalculationRead[]>([]);
  // Состояние загрузки
  const [isLoading, setIsLoading] = useState(true);
  // Состояние ошибки
  const [error, setError] = useState<string | null>(null);

  // Загрузка данных при монтировании компонента
  useEffect(() => {
    const fetchHistory = async () => {
      setIsLoading(true);
      setError(null);
      try {
        const data = await getCalculationHistory(0, 100); // Загружаем первые 100 записей
        setCalculations(data);
      } catch (err) {
        console.error("Failed to fetch calculation history:", err);
        setError('Не удалось загрузить историю расчетов.');
      } finally {
        setIsLoading(false);
      }
    };

    fetchHistory();
  }, []); // Пустой массив зависимостей означает, что эффект выполнится один раз при монтировании

  // --- Отображение состояний ---
  if (isLoading) {
    return <div className={styles.loading}>Загрузка истории...</div>;
  }

  if (error) {
    return <div className={styles.error}>Ошибка: {error}</div>;
  }

  if (calculations.length === 0) {
    return <div className={styles.empty}>История расчетов пуста.</div>;
  }

  return (
    // Используем класс из App.css и стили модуля
    <div className={`page-container ${styles.historyContainer}`}>
      <h2>История расчетов</h2>
      <table className={styles.table}>
        <thead>
          <tr>
            <th className={styles.th}>ID</th>
            <th className={styles.th}>Время запуска</th>
            <th className={styles.th}>Модель</th>
            <th className={styles.th}>Целевая функция (Остаток %)</th>
            <th className={styles.th}>Действия</th>
          </tr>
        </thead>
        <tbody className={styles.tbody}>
          {calculations.map((calc) => (
            <tr key={calc.id}>
              <td className={styles.td}>{calc.id}</td>
              <td className={styles.td}>{new Date(calc.timestamp).toLocaleString()}</td>
              <td className={styles.td}>{calc.model_name || '-'}</td>
              <td className={styles.td}>{calc.objective_score?.toFixed(2) ?? '-'}</td>
              <td className={styles.td}>
                <Link to={`/calculation/${calc.id}`}>Подробнее</Link>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
      {/* Здесь можно добавить пагинацию, если записей много */}
    </div>
  );
};

export default History; 